<?php

namespace Drupal\entity_timeline\Plugin\TimelineItemType\Deriver;

use Drupal\Component\Plugin\Exception\PluginNotFoundException;
use Drupal\Core\Entity\Plugin\Condition\Deriver\EntityBundle as SourceEntityBundle;

/**
 * Deriver that creates a timeline item for each entity type with bundles.
 */
class EntityBundle extends SourceEntityBundle {

  /**
   * {@inheritdoc}
   */
  public function getDerivativeDefinitions($base_plugin_definition): array {
    parent::getDerivativeDefinitions($base_plugin_definition);
    foreach ($this->derivatives as $id => $derivative) {
      try {
        $definition = $this->entityTypeManager->getDefinition(key($derivative['context_definitions']));
        $table = $definition->getDataTable() ?? $definition->getBaseTable();
        if (!$table || !\Drupal::database()->schema()->fieldExists($table, 'uid')) {
          // Base entity must implement base or data table and owner.
          unset($this->derivatives[$id]);
        }
      }
      catch (PluginNotFoundException $e) {
        unset($this->derivatives[$id]);
      }
    }
    return $this->derivatives;
  }

}
